@@ -20,7 +20,7 @@ def evaluate(qballcode: str):
             print(f"\033[91mLexer error: {e}\033[00m")
 
 
-def global_add(toadd: dict):
+def global_add(**toadd):
     i = 0
     while i < len(toadd):
         QBall.interpreter.global_vars.add(list(toadd.keys())[i], list(toadd.values())[i])
